#####################################################################
# Dinas and Foos, QJPS: Replication File                            #
# The National Effects of Subnational Representation:               #
# Access to Regional Parliaments and National Electoral Performance #
#####################################################################

#install.packages("gridExtra")
#install.packages("rdd")
#install.packages("ri")
#install.packages("dplyr")
#install.packages("MASS")
#install.packages("Matrix")
#install.packages("lattice")
#install.packages("rddtools")
#install.packages("ggplot2")
library(MASS)
library(Matrix)
library(lattice)
library(rdd)
library(foreign)
library(ri)
library(gridExtra)
library(dplyr)
library(ggplot2)


rm(list = ls())

setwd("/Use/your/cd")





##########
#Figure 1#
##########



graphing <- read.dta("Data.dta")

df1 <- graphing[graphing$forcing>-5 & graphing$forcing<5,]

df1$above = df1$forcing>=0


fig1full=ggplot(df1, aes(x = forcing, y = newper,shape=above)) + 
  geom_point() + geom_jitter() + ylim(0,25) + xlim(-5,5) + scale_shape_discrete(name  ="", labels=c("Below\n Threshold", "Above\n Threshold"))
figure1full=fig1full + stat_smooth(method = "loess",span=1) +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("Vote share at state election t") +
  ylab("State vote share at federal election t+1")  + theme(legend.position="none")
ggtitle("Full Sample")
figure1full

df2 <- graphing[graphing$forcing>-5 & graphing$forcing<5 & graphing$days<851,]

df2$above = df2$forcing>=0

fig1below=ggplot(df2, aes(x = forcing, y = newper,shape=above)) + 
  geom_point() + geom_jitter() + ylim(0,25) + xlim(-5,5) + scale_shape_discrete(name  ="", labels=c("Below\n Threshold", "Above\n Threshold"))
figure1below=fig1below + stat_smooth(method = "loess",span=1) +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("Vote share at state election t") +
  ylab("State vote share at federal election t+1")  + theme(legend.position="none")
ggtitle("Below Median")
figure1below


df3 <- graphing[graphing$forcing>-5 & graphing$forcing<5 & graphing$days>851,]

df3$above = df3$forcing>=0

fig1above=ggplot(df3, aes(x = forcing, y = newper,shape=above)) + 
  geom_point() + geom_jitter() + ylim(0,25) + xlim(-5,5) + scale_shape_discrete(name  ="", labels=c("Below\n Threshold", "Above\n Threshold"))
figure1above=fig1above + stat_smooth(method = "loess",span=1) +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("Vote share at state election t") +
  ylab("State vote share at federal election t+1")  + theme(legend.position="none")
ggtitle("Above Median")
figure1above


pdf("fig1a.pdf")
figure1full
dev.off()

pdf("fig1b.pdf")
figure1below
dev.off()

pdf("fig1c.pdf")
figure1above
dev.off()



#########
#Table 1#
#########

rm(list = ls())

newdata <- read.dta("Data.dta")


##########
#Column 1#
##########

all<-newdata[newdata$forcing<=5,]
newresultsall<-RDestimate(newper ~ forcing,data= all,cluster= all$stateyear) 
summary(newresultsall)

###################################################################
#Code used to distinguish between treated and control observations#
#Column 1, Part, 1, 2 and 3                                       #
###################################################################

obsIKtr <- all[all$forcing<4.612 & all$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-4.612 & all$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- all[all$forcing<2.306 & all$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-2.306 & all$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- all[all$forcing<9.223 & all$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-9.223 & all$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)



#######################
#Return to RD estmates#
#######################

newresultsall<-RDestimate(newper ~ forcing,data= all,bw=4, cluster= all$stateyear) 
summary(newresultsall)


obsIKtr <- all[all$forcing<4 & all$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-4 & all$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

##########
#Column 2#
##########

below <- newdata[newdata$forcing<=5 & newdata$days<851 ,]
newresultsbelow<-RDestimate(newper ~ forcing,data= below,cluster= below$stateyear) 
summary(newresultsbelow)

obsIKtr <- below[below$forcing<4.738 & below$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-4.738 & below$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- below[below$forcing<2.369 & below$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-2.369 & below$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- below[below$forcing<9.477 & below$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-9.477 & below$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


newresultsbelow<-RDestimate(newper ~ forcing,data= below,bw=4,cluster= below$stateyear) 
summary(newresultsbelow)

obsIKtr <- below[below$forcing<4 & below$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-4 & below$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


##########
#Column 3#
##########

above <- newdata[newdata$days>851 & newdata$forcing<=5,]
newresultsabove<-RDestimate(newper ~ forcing,data= above,cluster= above$stateyear) 
summary(newresultsabove)


obsIKtr <- above[above$forcing<5.482 & above$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-5.482 & above$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- above[above$forcing<2.741 & above$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-2.741 & above$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- above[above$forcing<10.964 & above$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-10.964 & above$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


newresultsabove<-RDestimate(newper ~ forcing,data= above, bw=4, cluster= above$stateyear) 
summary(newresultsabove)


obsIKtr <- above[above$forcing<4 & above$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-4 & above$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

################
#Placbo Outcome#
################

placeboabove <- newdata[newdata$days>851 & newdata$forcing<=5 & newdata$electiontypecode==1,]
abovepl<-RDestimate(newperlag1 ~ forcing,data= placeboabove, cluster= placeboabove$stateyear) 
summary(abovepl)



obsIKtr <- placeboabove[placeboabove$forcing<4.819 & placeboabove$forcing>=0,]
fit1<-lm(newperlag1 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- placeboabove[placeboabove$forcing>-4.819 & placeboabove$forcing<0,]
fit2<-lm(newperlag1 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- placeboabove[placeboabove$forcing<2.409 & placeboabove$forcing>=0,]
fit1<-lm(newperlag1 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- placeboabove[placeboabove$forcing>-2.409 & placeboabove$forcing<0,]
fit2<-lm(newperlag1 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- placeboabove[placeboabove$forcing<9.637 & placeboabove$forcing>=0,]
fit1<-lm(newperlag1 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- placeboabove[placeboabove$forcing>-9.637 & placeboabove$forcing<0,]
fit2<-lm(newperlag1 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)





#########################################
#Randomization Inference part: See RI.R##
#########################################

##########
#Figure 2#
##########

rm(list = ls())

newdata <- read.dta("Data.dta")

all<-newdata[newdata$forcing<=15,]




bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= all,bw=bw[i],cluster= all$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



below<-newdata[newdata$forcing<=15 & newdata$days<851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= below,bw=bw[i],cluster= below$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


above<-newdata[newdata$forcing<=15 & newdata$days>851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= above,bw=bw[i],cluster= above$yearstate)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


diffall=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.612, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Full Sample") +
  theme(plot.title = element_text(face="bold", size=6))


diffbe=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.738 , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Below Median") +
  theme(plot.title = element_text(face="bold", size=6))


diffab=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.482, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Above Median") +
  theme(plot.title = element_text(face="bold", size=6))

pdf("fig2.pdf")
grid.arrange(diffall, diffbe, diffab, ncol=3, nrow=3)
dev.off()


##########
#Table 2 #
##########


#See Stata.do file.


##########
#Figure 3#
##########

#########################################################################
#See Stata.do for the generation of the estimates used here for Figure 3#
#################################################################################
#Either use dataset generated by Stata.do or use dataset provided in Dataverse. #
#Unless change is made in Stata.do, code generates a dataset with the same name,# 
#i.e. "numberofdays.dta."########################################################
##########################


rm(list = ls())


numberdays <- read.dta("numberofdays.dta")

figure3=ggplot(numberdays, aes(x = id, y = estimate)) + 
  geom_point(data=numberdays, mapping=aes(x=id, y=estimate),size=1, color="black", fill="white", shape=22, position=position_jitter(w = 0.1, h = 0.1) )  +
  scale_x_continuous(breaks=c(0,100, 200, 300, 400, 500, 600, 700, 800, 900,1000, 1100, 1200, 1300, 1400, 1450)) + 
  theme(axis.title.x = element_text(size = 16), axis.title.y = element_text(size = 12), 
        axis.text.x = element_text(size = 10), plot.title = element_text(face="bold", size=16)) +
  xlab("More than ... days between state and national election") +
  ylab("LATE")   +  
  geom_smooth(aes(x = id, y = estimate), size=1, se = FALSE,color="blue", span=.8) 
figure3

pdf("fig3.pdf")
figure3
dev.off()


#########################
#Table 3: balance checks#
#########################

rm(list = ls())
newdata <- read.dta("Data.dta")

above <- newdata[newdata$days>851 ,]


newresults<-RDestimate(extremeright ~ forcing , data= above, cluster= above$stateyear) 
summary(newresults)

newresults<-RDestimate(east ~ forcing , data= above, cluster= above$stateyear) 
summary(newresults)

newresults<-RDestimate(year ~ forcing , data= above, cluster= above$stateyear) 
summary(newresults)

yearsq=above$year^2

newresults<-RDestimate(yearsq ~ forcing , data= above, cluster= above$stateyear) 
summary(newresults)

newresults<-RDestimate(post89 ~ forcing , data= above, cluster= above$stateyear) 
summary(newresults)

newresults<-RDestimate(fdp ~ forcing , data= above, cluster= above$stateyear) 
summary(newresults)

newresults<-RDestimate(greens ~ forcing , data= above, cluster= above$stateyear) 
summary(newresults)

newresults<-RDestimate(st1 ~ forcing , data= above, cluster= above$stateyear)  # Baden-Wurttemberg 
summary(newresults)

newresults<-RDestimate(st2 ~ forcing , data= above, cluster= above$stateyear) # Bayern
summary(newresults)

newresults<-RDestimate(st3 ~ forcing , data= above, cluster= above$stateyear) # Berlin
summary(newresults)

newresults<-RDestimate(st4 ~ forcing , data= above, cluster= above$stateyear) # Brandeburg
summary(newresults)

newresults<-RDestimate(st5 ~ forcing , data= above, cluster= above$stateyear) # Bremen
summary(newresults)

newresults<-RDestimate(st6 ~ forcing , data= above, cluster= above$stateyear) # Hamburg
summary(newresults)

newresults<-RDestimate(st7 ~ forcing , data= above, cluster= above$stateyear) # Hessen
summary(newresults)

newresults<-RDestimate(st8 ~ forcing , data= above, cluster= above$stateyear) # Mecklenburg-Vorpommern
summary(newresults)

newresults<-RDestimate(st9 ~ forcing , data= above, cluster= above$stateyear) #  Niedersachsen
summary(newresults)

newresults<-RDestimate(st10 ~ forcing , data= above, cluster= above$stateyear) #  Nordrhein-Westfalen
summary(newresults)

newresults<-RDestimate(st11 ~ forcing , data= above, cluster= above$stateyear) # Rheinland-Pfalz
summary(newresults)

newresults<-RDestimate(st12 ~ forcing , data= above, cluster= above$stateyear) # Saarland
summary(newresults)

newresults<-RDestimate(st13 ~ forcing , data= above, cluster= above$stateyear) # Sachsen
summary(newresults)

newresults<-RDestimate(st14 ~ forcing , data= above, cluster= above$stateyear) # Sachsen-Anhalt
summary(newresults)

newresults<-RDestimate(st15 ~ forcing , data= above, cluster= above$stateyear) # Schleswig-Holstein
summary(newresults)

newresults<-RDestimate(st16 ~ forcing , data= above, cluster= above$stateyear) # Thuringen
summary(newresults)

#########
#Table 4#
#########

rm(list = ls())
newdata <- read.dta("Data.dta")


parllow <- newdata[newdata$days>851 & newdata$parllow==1 & newdata$forcing<=5 , ]

newresults<-RDestimate(newper ~ forcing , data= parllow, cluster= parllow$yearstate) 
summary(newresults)

obsIKtr <- parllow[parllow$forcing<4.844 & parllow$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- parllow[parllow$forcing>-4.844 & parllow$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

newresults<-RDestimate(newper ~ forcing , data= parllow,bw=4, cluster= parllow$yearstate) 
summary(newresults)

obsIKtr <- parllow[parllow$forcing<4 & parllow$forcing>=0,]
fit7<-lm(newper ~ forcing, data=obsIKtr)
summary(fit7)
nobs(fit7)

obsIKcn <- parllow[parllow$forcing>-4 & parllow$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


parlhigh <- newdata[newdata$days>851 & newdata$parllow==0 & newdata$forcing<=5, ]

newresults<-RDestimate(newper ~ forcing , data= parlhigh, cluster= parlhigh$yearstate) 
summary(newresults)

obsIKtr <- parlhigh[parlhigh$forcing<4.037 & parlhigh$forcing>=0,]
fit1<-lm(newper ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- parlhigh[parlhigh$forcing>-4.037 & parlhigh$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

newresults<-RDestimate(newper ~ forcing , data= parlhigh,bw=4, cluster= parlhigh$yearstate) 
summary(newresults)

obsIKtr <- parlhigh[parlhigh$forcing<4 & parlhigh$forcing>=0,]
fit7<-lm(newper ~ forcing, data=obsIKtr)
summary(fit7)
nobs(fit7)

obsIKcn <- parlhigh[parlhigh$forcing>-4 & parlhigh$forcing<0,]
fit2<-lm(newper ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


#########
#Table 5#
#########

rm(list = ls())
membership <-read.dta("membership.dta")


results<-RDestimate(newmembers ~ forcing , data=membership)  
summary(results)

obsIKtr <- membership[membership$forcing<3.449  & membership$forcing>=0,]
fit1<-lm(newmembers ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-3.449 & membership$forcing<0,]
fit2<-lm(newmembers ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

obsIKtr <- membership[membership$forcing<1.725   & membership$forcing>=0,]
fit1<-lm(newmembers ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-1.725  & membership$forcing<0,]
fit2<-lm(newmembers ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- membership[membership$forcing<6.898   & membership$forcing>=0,]
fit1<-lm(newmembers ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-6.898  & membership$forcing<0,]
fit2<-lm(newmembers ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


results<-RDestimate(newmembers ~ forcing ,bw=4, data=membership)  
summary(results)


obsIKtr <- membership[membership$forcing<4   & membership$forcing>=0,]
fit1<-lm(newmembers ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4  & membership$forcing<0,]
fit2<-lm(newmembers ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


results<-RDestimate(newmembers2 ~ forcing , data=membership)  
summary(results)


obsIKtr <- membership[membership$forcing<3.567   & membership$forcing>=0,]
fit1<-lm(newmembers2 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-3.567  & membership$forcing<0,]
fit2<-lm(newmembers2 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

obsIKtr <- membership[membership$forcing<1.784    & membership$forcing>=0,]
fit1<-lm(newmembers2 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-1.784   & membership$forcing<0,]
fit2<-lm(newmembers2 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

obsIKtr <- membership[membership$forcing<7.134    & membership$forcing>=0,]
fit1<-lm(newmembers2 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-7.134   & membership$forcing<0,]
fit2<-lm(newmembers2 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)



results<-RDestimate(newmembers2 ~ forcing ,bw=4, data=membership)  
summary(results)


obsIKtr <- membership[membership$forcing<4    & membership$forcing>=0,]
fit1<-lm(newmembers2 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4   & membership$forcing<0,]
fit2<-lm(newmembers2 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


results<-RDestimate(newmembers3 ~ forcing , data=membership)  
summary(results)

obsIKtr <- membership[membership$forcing<4.254     & membership$forcing>=0,]
fit1<-lm(newmembers3 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4.254    & membership$forcing<0,]
fit2<-lm(newmembers3 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- membership[membership$forcing<2.127     & membership$forcing>=0,]
fit1<-lm(newmembers3 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-2.127    & membership$forcing<0,]
fit2<-lm(newmembers3 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

obsIKtr <- membership[membership$forcing<8.508      & membership$forcing>=0,]
fit1<-lm(newmembers3 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-8.508     & membership$forcing<0,]
fit2<-lm(newmembers3 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


results<-RDestimate(newmembers3 ~ forcing ,bw=4, data=membership)  
summary(results)

obsIKtr <- membership[membership$forcing<4      & membership$forcing>=0,]
fit1<-lm(newmembers3 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4     & membership$forcing<0,]
fit2<-lm(newmembers3 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

results<-RDestimate(newmembers4 ~ forcing , data=membership)  
summary(results)


obsIKtr <- membership[membership$forcing<4.266      & membership$forcing>=0,]
fit1<-lm(newmembers4 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4.266     & membership$forcing<0,]
fit2<-lm(newmembers4 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- membership[membership$forcing<2.133       & membership$forcing>=0,]
fit1<-lm(newmembers4 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-2.133      & membership$forcing<0,]
fit2<-lm(newmembers4 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

obsIKtr <- membership[membership$forcing<8.531       & membership$forcing>=0,]
fit1<-lm(newmembers4 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-8.531      & membership$forcing<0,]
fit2<-lm(newmembers4 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)






results<-RDestimate(newmembers4 ~ forcing ,bw=4, data=membership)  
summary(results)

obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(newmembers4 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(newmembers4 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


prmem1 <- RDestimate(prevmembers ~ forcing ,bw=4, data=membership)  
summary(prmem1)

obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(prevmembers ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(prevmembers ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

prmem2 <- RDestimate(prevmembers2 ~ forcing ,bw=4, data=membership)  
summary(prmem2)

obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(prevmembers2 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(prevmembers2 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

prmem3 <- RDestimate(prevmembers3 ~ forcing ,bw=4, data=membership)  
summary(prmem3)



obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(prevmembers3 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(prevmembers3 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)



prmem4 <- RDestimate(prevmembers4 ~ forcing ,bw=4, data=membership)  
summary(prmem4)

obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(prevmembers4 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(prevmembers4 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


results<-RDestimate(membdif1 ~ forcing,bw=4, data=membership)  
summary(results)


obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(membdif1 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(membdif1 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

results<-RDestimate(membdif2 ~ forcing,bw=4, data=membership)  
summary(results)

obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(membdif2 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(membdif2 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

results<-RDestimate(membdif3 ~ forcing,bw=4, data=membership)  
summary(results)

obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(membdif3 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(membdif3 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


results<-RDestimate(membdif4 ~ forcing,bw=4, data=membership)  
summary(results)


obsIKtr <- membership[membership$forcing<4       & membership$forcing>=0,]
fit1<-lm(membdif4 ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- membership[membership$forcing>-4      & membership$forcing<0,]
fit2<-lm(membdif4 ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


#########################################
#Randomization Inference part: See RI.R##
#########################################


##########
#Figure 4#
##########


#See Media.R


#########
#Table 6#
#########


#See Stata.do




########## 
#Appendix# 
########## 


########### 
#Table A.1# 
########### 

#See RI.R

########### 
#Table A.2# 
########### 



rm(list = ls())
newdata <- read.dta("Data.dta")
above <- newdata[newdata$days>851 & newdata$forcing<=5,]

feyear<-factor(above$year, exclude = NA)

abovefeyear<-RDestimate(newper ~ forcing | feyear ,data= above, cluster= above$stateyear) 
summary(abovefeyear)


feparty<-factor(above$partycode, exclude = NA)

abovefeparty<-RDestimate(newper ~ forcing | feparty ,data= above, cluster= above$stateyear) 
summary(abovefeparty)

festate<-factor(above$statecode, exclude = NA)

abovefestate<-RDestimate(newper ~ forcing | festate ,data= above, cluster= above$stateyear) 
summary(abovefestate)


fepartyyear<-factor(above$partyyear, exclude = NA)

abovefepartyyear<-RDestimate(newper ~ forcing | fepartyyear ,data= above, cluster= above$stateyear) 
summary(abovefepartyyear)


festateyear<-factor(above$stateyear, exclude = NA)

abovefestateyear<-RDestimate(newper ~ forcing | festateyear ,data= above, cluster= above$stateyear) 
summary(abovefestateyear)


festateparty<-factor(above$stateparty, exclude = NA)

abovefestateparty<-RDestimate(newper ~ forcing | stateparty ,data= above, cluster= above$stateyear) 
summary(abovefestateparty)







###########
#Table A.3#
###########


rm(list = ls())
newdata <- read.dta("seats.dta")
all<-newdata[newdata$forcing<=5,]
seatsall<-RDestimate(seats_national_recoded ~ forcing,data= all,cluster= all$yearstate) 
summary(seatsall)

obsIKtr <- all[all$forcing<4.821 & all$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-4.821 & all$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- all[all$forcing<2.411 & all$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-2.411 & all$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- all[all$forcing<9.642 & all$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-9.642 & all$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

seatsall4<-RDestimate(seats_national_recoded ~ forcing,data= all,bw=4,cluster= all$yearstate) 
summary(seatsall4)

obsIKtr <- all[all$forcing<4 & all$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- all[all$forcing>-4 & all$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


below <- newdata[newdata$days<851 & newdata$forcing<=5,]

seatsbelow<-RDestimate(seats_national_recoded ~ forcing,data= below,cluster= below$yearstate) 
summary(seatsbelow)

obsIKtr <- below[below$forcing<3.509 & below$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-3.509 & below$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- below[below$forcing<1.754 & below$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-1.754 & below$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- below[below$forcing<7.017 & below$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-7.017 & below$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


seatsbelow4<-RDestimate(seats_national_recoded ~ forcing,data= below,bw=4,cluster= below$yearstate) 
summary(seatsbelow4)

obsIKtr <- below[below$forcing<4 & below$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- below[below$forcing>-4 & below$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


above <- newdata[newdata$days>851 & newdata$forcing<=5,]
seatsabove<-RDestimate(seats_national_recoded ~ forcing,data= above,cluster= above$yearstate) 
summary(seatsabove)

obsIKtr <- above[above$forcing<5.019 & above$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-5.019 & above$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- above[above$forcing<2.510 & above$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-2.510 & above$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- above[above$forcing<10.039 & above$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-10.039 & above$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

seatsabove4<-RDestimate(seats_national_recoded ~ forcing,data= above,bw=4,cluster= above$yearstate) 
summary(seatsabove4)

obsIKtr <- above[above$forcing<4 & above$forcing>=0,]
fit1<-lm(seats_national_recoded ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-4 & above$forcing<0,]
fit2<-lm(seats_national_recoded ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

seatsplacebo<-RDestimate(seats_national_recoded_lag ~ forcing,data= above, cluster= above$yearstate) 
summary(seatsplacebo)

obsIKtr <- above[above$forcing<5.059 & above$forcing>=0,]
fit1<-lm(seats_national_recoded_lag ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-5.059 & above$forcing<0,]
fit2<-lm(seats_national_recoded_lag ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- above[above$forcing<2.530 & above$forcing>=0,]
fit1<-lm(seats_national_recoded_lag ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-2.530 & above$forcing<0,]
fit2<-lm(seats_national_recoded_lag ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)


obsIKtr <- above[above$forcing<10.118 & above$forcing>=0,]
fit1<-lm(seats_national_recoded_lag ~ forcing, data=obsIKtr)
summary(fit1)
nobs(fit1)

obsIKcn <- above[above$forcing>-10.118 & above$forcing<0,]
fit2<-lm(seats_national_recoded_lag ~ forcing, data=obsIKcn)
summary(fit2)
nobs(fit2)

############
#Figure A.1#
############

################
#State clusters#
################

rm(list = ls())

newdata <- read.dta("Data.dta")

all<-newdata[newdata$forcing<=15,]



bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= all,bw=bw[i],cluster= all$statecode)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



below<-newdata[newdata$forcing<=15 & newdata$days<851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= below,bw=bw[i],cluster= below$statecode)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


above<-newdata[newdata$forcing<=15 & newdata$days>851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= above,bw=bw[i],cluster= above$statecode)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



stateall=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.612, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Full Sample, State Clusters") +
  theme(plot.title = element_text(face="bold", size=6))

statebe=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.738 , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Below Median, State Clusters") +
  theme(plot.title = element_text(face="bold", size=6))

stateab=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.482, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Above Median, State Clusters") +
  theme(plot.title = element_text(face="bold", size=6))







################
#Year clusters#
################



bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= all,bw=bw[i],cluster= all$year)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



below<-newdata[newdata$forcing<=15 & newdata$days<851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= below,bw=bw[i],cluster= below$year)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


above<-newdata[newdata$forcing<=15 & newdata$days>851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= above,bw=bw[i],cluster= above$year)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


yearall=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.612, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Full Sample, Year Clusters") +
  theme(plot.title = element_text(face="bold", size=6))

yearbe=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.738 , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Below Median, Year Clusters") +
  theme(plot.title = element_text(face="bold", size=6))

yearab=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.482, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Above Median, Year Clusters") +
  theme(plot.title = element_text(face="bold", size=6))


###############
#No clustering#
###############





bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= all,bw=bw[i])  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



below<-newdata[newdata$forcing<=15 & newdata$days<851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= below,bw=bw[i])  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


above<-newdata[newdata$forcing<=15 & newdata$days>851,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= above,bw=bw[i])  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


noneall=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.612, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Full Sample, No Clustering") +
  theme(plot.title = element_text(face="bold", size=6))

nonebe=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.738 , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Below Median, No Clustering") +
  theme(plot.title = element_text(face="bold", size=6))

noneab=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.482, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Above Median, No Clustering") +
  theme(plot.title = element_text(face="bold", size=6))

pdf("figA1.pdf")
grid.arrange(noneall, nonebe,noneab, yearall, yearbe, yearab, stateall, statebe, stateab, ncol=3, nrow=3)
dev.off()






############
#Figure A.2#
############



rm(list = ls())

newdata <- read.dta("Data.dta")

allapp<-newdata[newdata$forcing<=15 & (newdata$year<1959 | newdata$year>1969),]



bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= allapp,bw=bw[i],cluster= allapp$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



belowapp<-newdata[newdata$forcing<=15 & newdata$days<851 & (newdata$year<1959 | newdata$year>1969) ,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= belowapp,bw=bw[i],cluster= belowapp$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


aboveapp<-newdata[newdata$forcing<=15 & newdata$days>851 & (newdata$year<1959 | newdata$year>1969),]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= aboveapp,bw=bw[i],cluster= aboveapp$yearstate)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


diffallapp=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.369, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Full Sample") +
  theme(plot.title = element_text(face="bold", size=6))

diffbeapp=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.844 , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Below Median") +
  theme(plot.title = element_text(face="bold", size=6))

diffabapp=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.017, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-5,6)) + 
  ggtitle("Above Median") +
  theme(plot.title = element_text(face="bold", size=6))

pdf("figA2.pdf")
grid.arrange(diffallapp, diffbeapp, diffabapp, ncol=3, nrow=3)
dev.off()


###########
#Table A.4#
###########


#See stata.do




############
#Figure A.3#
############


rm(list = ls())


newdata <- read.dta("Data.dta")

all<-newdata[newdata$forcing<=15,]



bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= all,bw=bw[i],cluster= all$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



below<-newdata[newdata$forcing<=15 & newdata$days<912,]



bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= below,bw=bw[i],cluster= below$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


above<-newdata[newdata$forcing<=15 & newdata$days>912,]


bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= above,bw=bw[i],cluster= above$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)




diffall=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.612, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-6,6)) + 
  ggtitle("Full Sample") +
  theme(plot.title = element_text(face="bold", size=6))

diffbe=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.997  , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-6,6)) + 
  ggtitle("Below 2.5 Years") +
  theme(plot.title = element_text(face="bold", size=6))

diffab=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.551, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-6,6)) + 
  ggtitle("Above 2.5 Years") +
  theme(plot.title = element_text(face="bold", size=6))

pdf("figA3.pdf")
grid.arrange(diffall, diffbe, diffab, ncol=3, nrow=3)
dev.off()


############
#Figure A.4#
############


rm(list = ls())
newdata <- read.dta("Data.dta")

sortingall <- newdata[newdata$forcing<=5 & newdata$forcing>=-5 & newdata$electiontypecode==1,]
DCdensity(sortingall$forcing,plot=TRUE,ext.out =TRUE)
title(xlab="State Vote Share")
abline(v=0, lty=1, col="grey50")

below <- newdata[newdata$days<851 ,]

sortingbelow <- below[below$forcing<=5 & below$forcing>=-5 & below$electiontypecode==1,]
DCdensity(sortingbelow$forcing,plot=TRUE,ext.out =TRUE)
title(xlab="X: with the Greens (Below 851)",ylab="Density")
abline(v=0, lty=1, col="grey50")


above <- newdata[newdata$days>851 ,]

sortingabove <- above[above$forcing<=5 & above$forcing>=-5 & above$electiontypecode==1,]
DCdensity(sortingabove$forcing,plot=TRUE,bw=4,ext.out =TRUE)
title(xlab="X: with the Greens (Below 851)",ylab="Density")
abline(v=0, lty=1, col="grey50")


sortingall2 <- newdata[newdata$forcing<=5 & newdata$forcing>=-5 & newdata$electiontypecode==1 & (newdata$year>1969 | newdata$year<1959),]
DCdensity(sortingall2$forcing,plot=TRUE,ext.out =TRUE)
title(xlab="State Vote Share")
abline(v=0, lty=1, col="grey50")

below <- newdata[newdata$days<851 ,]

sortingbelow2 <- below[below$forcing<=5 & below$forcing>=-5 & below$electiontypecode==1 & (below$year>1969 | below$year<1959),]
DCdensity(sortingbelow2$forcing,plot=TRUE,ext.out =TRUE)
title(xlab="X: with the Greens (Below 851)",ylab="Density")
abline(v=0, lty=1, col="grey50")


above <- newdata[newdata$days>851 ,]

sortingabove2 <- above[above$forcing<=5 & above$forcing>=-5 & above$electiontypecode==1 & (above$year>1969 | above$year<1959),]
DCdensity(sortingabove2$forcing,plot=TRUE,ext.out =TRUE)
title(xlab="X: with the Greens (Below 851)",ylab="Density")
abline(v=0, lty=1, col="grey50")




sd1<-data.frame(DCdensity(sortingall$forcing,plot=TRUE,ext.out =TRUE))
sd2<-data.frame(DCdensity(sortingbelow$forcing,plot=TRUE,ext.out =TRUE))
sd3<-data.frame(DCdensity(sortingabove$forcing,plot=TRUE,ext.out =TRUE))
sd4<-data.frame(DCdensity(sortingall2$forcing,plot=TRUE,ext.out =TRUE))
sd5<-data.frame(DCdensity(sortingbelow2$forcing,plot=TRUE,ext.out =TRUE))
sd6<-data.frame(DCdensity(sortingabove2$forcing,plot=TRUE,ext.out =TRUE))


sd1$above = sd1$data.cellmp>=0
sort1=ggplot(sd1, aes(x = data.cellmp, y = data.cellval, shape=above)) + 
  geom_point() + geom_jitter() + ylim(-.1,.8) + xlim(-5,5) + stat_smooth() +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("State Vote share") +
  ylab("Density")   + theme(legend.position="none") + ggtitle("Full Sample, All Obs.") +  theme(plot.title=element_text(size=10))
sort1

sd2$above = sd2$data.cellmp>=0
sort2=ggplot(sd2, aes(x = data.cellmp, y = data.cellval, shape=above)) + 
  geom_point() + geom_jitter() + ylim(-.1,.8) + xlim(-5,5) + stat_smooth() +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("State Vote share") +
  ylab("Density")   + theme(legend.position="none") + ggtitle("Below Median, All Obs.") + theme(plot.title=element_text(size=10))
sort2


sd3$above = sd3$data.cellmp>=0
sort3=ggplot(sd3, aes(x = data.cellmp, y = data.cellval, shape=above)) + 
  geom_point() + geom_jitter() + ylim(-.1,.8) + xlim(-5,5) + stat_smooth() +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("State Vote share") +
  ylab("Density")   + theme(legend.position="none") + ggtitle("Above Median, All Obs.") + theme(plot.title=element_text(size=10))
sort3

sd4$above = sd4$data.cellmp>=0
sort4=ggplot(sd4, aes(x = data.cellmp, y = data.cellval, shape=above)) + 
  geom_point() + geom_jitter() + ylim(-.1,.8) + xlim(-5,5) + stat_smooth() +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("State Vote share") +
  ylab("Density")   + theme(legend.position="none") + ggtitle("Full Sample, Excl. 1959-69") + theme(plot.title=element_text(size=10))
sort4


sd5$above = sd5$data.cellmp>=0
sort5=ggplot(sd5, aes(x = data.cellmp, y = data.cellval, shape=above)) + 
  geom_point() + geom_jitter() + ylim(-.1,.8) + xlim(-5,5) + stat_smooth() +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("State Vote share") +
  ylab("Density")   + theme(legend.position="none") + ggtitle("Below Median, Excl. 1959-69") + theme(plot.title=element_text(size=10))
sort5

sd6$above = sd6$data.cellmp>=0
sort6=ggplot(sd6, aes(x = data.cellmp, y = data.cellval, shape=above)) + 
  geom_point() + geom_jitter() + ylim(-.1,.8) + xlim(-5,5) + stat_smooth() +
  geom_vline(xintercept = 0, linetype = "dashed") +
  xlab("State Vote share") +
  ylab("Density")   + theme(legend.position="none") + ggtitle("Above Median, Excl. 1959-69") + theme(plot.title=element_text(size=10))
sort6

pdf("figA4.pdf")
grid.arrange(sort1, sort2, sort3, sort4,sort5,sort6, ncol=3, nrow=3)
dev.off()

###########
#Table A.5#
###########


rm(list = ls())
newdata <- read.dta("Data.dta")

all <- newdata[newdata$forcing<=5 ,]


newresults<-RDestimate(extremeright ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(east ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(year ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

yearsq=all$year^2

newresults<-RDestimate(yearsq ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(post89 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(fdp ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(greens ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)


newresults<-RDestimate(st1 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)


newresults<-RDestimate(st2 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st3 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st4 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st5 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st6 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st7 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st8 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st9 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st10 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st11 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st12 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st13 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st14 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st15 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)

newresults<-RDestimate(st16 ~ forcing , data= all, cluster= all$stateyear) 
summary(newresults)


############
#Figure A.5#
############

rm(list = ls())

newdata <- read.dta("Data.dta")

allapp<-newdata[newdata$forcing<=15 & newdata$statecode!=12 & newdata$statecode!=16,]


bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= allapp,bw=bw[i],cluster= allapp$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



belowapp<-newdata[newdata$forcing<=15 & newdata$days<851 &  newdata$statecode!=12 & newdata$statecode!=16 ,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= belowapp,bw=bw[i],cluster= belowapp$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


aboveapp<-newdata[newdata$forcing<=15 & newdata$days>851 & newdata$statecode!=12 & newdata$statecode!=16,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= aboveapp,bw=bw[i],cluster= aboveapp$yearstate)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


diffallapp=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.091, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-6,6)) + 
  ggtitle("Full Sample") +
  theme(plot.title = element_text(face="bold", size=6))

diffbeapp=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.315  , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-6,6)) + 
  ggtitle("Below Median") +
  theme(plot.title = element_text(face="bold", size=6))

diffabapp=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.437, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6), limits=c(-6,6)) + 
  ggtitle("Above Median") +
  theme(plot.title = element_text(face="bold", size=6))

pdf("figA5.pdf")
grid.arrange(diffallapp, diffbeapp, diffabapp, ncol=3, nrow=3)
dev.off()



###########
#Table A.6#
###########

rm(list = ls())
newdata <- read.dta("Data.dta")



withinbelow <- newdata[newdata$days>851 & newdata$forcing<0  ,]

newresults<-RDestimate(newper ~ forcing , data= withinbelow,cutpoint=-4.3, cluster= withinbelow$stateyear) 
summary(newresults)

obsIKcn <- newdata[newdata$days>851 & newdata$forcing<   -4.3 & newdata$forcing>   -5.1  ,]  # "5.1" arbitrary beyond-range value, to avoid NAs 
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=   -4.3 & newdata$forcing< -2.895  ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)



newresults<-RDestimate(newper ~ forcing , data= withinbelow,cutpoint=-4.3,bw=2.5, cluster= withinbelow$stateyear) 
summary(newresults)


obsIKcn <- newdata[newdata$days>851 & newdata$forcing<   -4.3 & newdata$forcing>   -6.8  ,]
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=   -4.3 & newdata$forcing< -1.8  ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)


newresults<-RDestimate(newper ~ forcing , data= withinbelow,cutpoint=-3.765497, cluster= withinbelow$stateyear) 
summary(newresults)

obsIKcn <- newdata[newdata$days>851 & newdata$forcing<   -3.765497 & newdata$forcing>   -4.940497  ,]
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=   -3.765497 & newdata$forcing<  -2.590  ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)

newresults<-RDestimate(newper ~ forcing , data= withinbelow,cutpoint=-3.765497,bw=2.5, cluster= withinbelow$stateyear) 
summary(newresults)

obsIKcn <- newdata[newdata$days>851 & newdata$forcing<   -3.765497 & newdata$forcing>  -6.265497  ,]
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=   -3.765497 & newdata$forcing< -1.265497  ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)


withinab <- newdata[newdata$days>851 & newdata$forcing>=0  & newdata$forcing<=5,]

newresults<-RDestimate(newper ~ forcing , data= withinab,cutpoint=2,cluster= withinab$stateyear) 
summary(newresults)

obsIKcn <- newdata[newdata$days>851 & newdata$forcing<   2 & newdata$forcing>  0.8856  ,]
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=2 & newdata$forcing<3.1144  ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)


newresults<-RDestimate(newper ~ forcing , data= withinab,cutpoint=2,bw=2.5,cluster= withinab$stateyear) 
summary(newresults)

obsIKcn <- newdata[newdata$days>851 & newdata$forcing<   2 & newdata$forcing>= 0  ,]
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=2 & newdata$forcing<4.5  ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)


newresults<-RDestimate(newper ~ forcing , data= withinab,cutpoint= 2.108407, cluster= withinab$stateyear) 
summary(newresults)

obsIKcn <- newdata[newdata$days>851 & newdata$forcing<  2.108407 & newdata$forcing> .516507  ,]
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=2.108407 & newdata$forcing<  3.700307  ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)

newresults<-RDestimate(newper ~ forcing , data= withinab,cutpoint= 2.108407,bw=2.5, cluster= withinab$stateyear) 
summary(newresults)

obsIKcn <- newdata[newdata$days>851 & newdata$forcing<  2.108407 & newdata$forcing>= 0 ,]
fit1<-lm(newper ~ forcing, data=obsIKcn)
summary(fit1)
nobs(fit1)

obsIKtr <- newdata[newdata$days>851 & newdata$forcing>=2.108407 & newdata$forcing<  4.608407 ,]
fit2<-lm(newper ~ forcing, data=obsIKtr)
summary(fit2)
nobs(fit2)


###########
#Table A.7#
###########

#Raw Data.


############
#Figure A.6#
############

#See Media.R


############
#Figure A.7#
############


rm(list = ls())


newdata <- read.dta("Data.dta")

allapp<-newdata[newdata$forcing<=15 & newdata$fdp==0,]




bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= allapp,bw=bw[i],cluster= allapp$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df1 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)



belowapp<-newdata[newdata$forcing<=15 & newdata$days<851 & newdata$fdp==0,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= belowapp,bw=bw[i],cluster= belowapp$stateyear)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df2 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


aboveapp<-newdata[newdata$forcing<=15 & newdata$days>851 & newdata$fdp==0,]

bw <- seq(1,7,0.01)
est <- rep(NA,length(bw))
se <- rep(NA,length(bw))
rdd.list <- list()
for(i in 1:length(bw)){
  rdd.list[[i]] <- RDestimate(newper ~ forcing,data= aboveapp,bw=bw[i],cluster= aboveapp$yearstate)  
  est[i] <- rdd.list[[i]]$est[1]
  se[i] <- rdd.list[[i]]$se[1]
}

df3 <- data.frame(
  bw=bw,
  est=est,
  ci.hi=est+1.96*se,
  ci.lo=est-1.96*se)


nofdpall=ggplot(df1, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 5.112, linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-7,-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6,7,8,9,10), limits=c(-7,10)) + 
  ggtitle("Full Sample") +
  theme(plot.title = element_text(face="bold", size=6))

nofdpbelow=ggplot(df2, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept = 4.887    , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-7,-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6,7,8,9,10), limits=c(-7,10)) + 
  ggtitle("Below Median") +
  theme(plot.title = element_text(face="bold", size=6))

nofdpabove=ggplot(df3, aes(x = bw, y = est)) +  
  geom_line(aes(x = bw, y = est),color="blue", size=1) + 
  geom_line(aes(x = bw, y = ci.hi ), linetype="dashed") +
  geom_line(aes(x = bw, y = ci.lo ), linetype="dashed") +
  geom_hline(yintercept = 0, color = "gray") +
  geom_vline(xintercept =   6.655   , linetype = "solid",color="#999999",size=.25) +
  xlab("Bandwidth") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=c(1,2,3,4,5,6,7)) + 
  scale_y_continuous(breaks=c(-7,-6,-5,-4,-3,-2,-1, 0,1, 2, 3, 4, 5, 6,7,8,9,10), limits=c(-7,10)) + 
  ggtitle("Above Median") +
  theme(plot.title = element_text(face="bold", size=6))

pdf("figA7.pdf")
grid.arrange(nofdpall, nofdpbelow, nofdpabove, ncol=3, nrow=3)
dev.off()


###########
#Table A.8#
###########

#See stata.do


###########
#Table A.9#
###########

#See stata.do


############
#Figure A.8#
############


rm(list = ls())

####################################################################################
#You need to use the Stata.do code to generate the estimates used here for Figure 3#
####################################################################################



firstbe <- read.dta("yearbe.dta")
firstab <- read.dta("yearab.dta")
secondbe <- read.dta("yearbesq.dta")
secondab <- read.dta("yearabsq.dta")

thirdbe <- read.dta("yearbecb.dta")
thirdab <- read.dta("yearabcb.dta")



year1be=ggplot(firstbe, aes(x = id, y = estimate)) + 
  geom_pointrange(data=firstbe, mapping=aes(x=id, y=estimate, ymin=max95, ymax=min95),size=.5, color="gray60", fill="white", shape=22)  +
  geom_smooth(aes(x = id, y = estimate), size=2, se = FALSE, span=1.3,color="black") +
  xlab("Time (in Years)") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=seq(1950, 2013, 10)) + 
  scale_y_continuous(limits=c(-12,12)) + 
  ggtitle("Below Median, One Polynomial") +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6), axis.title.x =element_text(color = "black", size = 6), axis.text.x = element_text(size=5), plot.title = element_text(size =6)) 


year1ab=ggplot(firstab, aes(x = id, y = estimate)) + 
  geom_pointrange(data=firstab, mapping=aes(x=id, y=estimate, ymin=max95, ymax=min95),size=.5, color="gray60", fill="white", shape=22)  +
  geom_smooth(aes(x = id, y = estimate), size=2, se = FALSE, span=1.3,color="black") +
  xlab("Time (in Years)") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=seq(1950, 2013, 10)) + 
  scale_y_continuous(limits=c(-12,12)) + 
  ggtitle("Above Median, One Polynomial") +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6), axis.title.x =element_text(color = "black", size = 6), axis.text.x = element_text(size=5), plot.title = element_text(size = 6))


year2be=ggplot(secondbe, aes(x = id, y = estimate)) + 
  geom_pointrange(data=secondbe, mapping=aes(x=id, y=estimate, ymin=max95, ymax=min95),size=.5, color="gray60", fill="white", shape=22)  +
  geom_smooth(aes(x = id, y = estimate), size=2, se = FALSE, span=1.3,color="black") +
  xlab("Time (in Years)") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=seq(1950, 2013, 10)) + 
  scale_y_continuous(limits=c(-12,12)) + 
  ggtitle("Below Median, Two Polynomials") +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6), axis.title.x =element_text(color = "black", size = 6), axis.text.x = element_text(size=5), plot.title = element_text(size = 6))


year2ab=ggplot(secondab, aes(x = id, y = estimate)) + 
  geom_pointrange(data=secondab, mapping=aes(x=id, y=estimate, ymin=max95, ymax=min95),size=.5, color="gray60", fill="white", shape=22)  +
  geom_smooth(aes(x = id, y = estimate), size=2, se = FALSE, span=1.3,color="black") +
  xlab("Time (in Years)") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=seq(1950, 2013, 10)) + 
  scale_y_continuous(limits=c(-12,12)) + 
  ggtitle("Above Median, Two Polynomials") +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6), axis.title.x =element_text(color = "black", size = 6), axis.text.x = element_text(size=5), plot.title = element_text(size = 6))


year3be=ggplot(thirdbe, aes(x = id, y = estimate)) + 
  geom_pointrange(data=thirdbe, mapping=aes(x=id, y=estimate, ymin=max95, ymax=min95),size=.5, color="gray60", fill="white", shape=22)  +
  geom_smooth(aes(x = id, y = estimate), size=2, se = FALSE, span=1.3,color="black") +
  xlab("Time (in Years)") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=seq(1950, 2013, 10)) + 
  scale_y_continuous(limits=c(-12,12)) + 
  ggtitle("Below Median, Three Polynomials") +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6), axis.title.x =element_text(color = "black", size = 6), axis.text.x = element_text(size=5), plot.title = element_text(size = 6))




year3ab=ggplot(thirdab, aes(x = id, y = estimate)) + 
  geom_pointrange(data=thirdab, mapping=aes(x=id, y=estimate, ymin=max95, ymax=min95),size=.5, color="gray60", fill="white", shape=22) + 
  geom_smooth(aes(x = id, y = estimate), size=2, se = FALSE, span=1.3,color="black") + 
  xlab("Time (in Years)") + theme(axis.title.x =element_text(color = "black", size = 6)) +
  scale_x_continuous(breaks=seq(1950, 2013, 10)) + 
  scale_y_continuous(limits=c(-12,12)) + 
  ggtitle("Above Median, Three Polynomials") +
  ylab("LATE")   + theme(axis.title.y =element_text(color = "black", size = 6), axis.title.x =element_text(color = "black", size = 6), axis.text.x = element_text(size=5),plot.title = element_text(size = 6))

pdf("figA8.pdf")
grid.arrange(year1be,year2be,year3be, year1ab, year2ab, year3ab, ncol=3, nrow=3)
dev.off()


############
#Table A.10#
############

#Raw Data

############
#Figure A.9#
############

#See RI.R


