set more off

cd "/Use/your/cd"



use Data.dta, clear


 


#################################################
#Recoding code for the key variables of interest#
#################################################


################################################################################
#Outcome (Vote share in Federal election t in state s): newper                 #
#Forcing (Vote share in previous state election in state s): newpercentagestate# 
################################################################################


drop tr forcing forcsqtr trforc forccbtr forcthtr forcsq forccb forcth 

gen forcing=newpercentagestate-5

gen tr=0
replace tr=1 if forcing>=0
replace tr=. if forcing==.

gen forcsq=forcing^2
gen forccb=forcing^3
gen forcth=forcing^4

gen forctr=forcing*tr
gen forcsqtr=forcsq*tr
gen forccbtr=forccb*tr
gen forcthtr=forcth*tr



#########################################################################################
#Distinguihsing below & above median: main analysis and within-group effects (Table A.6)#
#########################################################################################

sum days if newper!=. & forcing!=. ,d
sum forcing if newper!=. & forcing!=.  & forcing<0, d
sum forcing if newper!=. & forcing!=.  & forcing>=0 & forcing<=5, d




###########################
#Recoding code for Table 2#
###########################

drop after  

gen after=0
replace after=1 if days>851
gen trafter=tr*after
gen forcingafter=forcing*after
gen forctrafter=forcing*tr*after



gen forcingsqafter=forcsq*after
gen forcsqtrafter=forcsq*tr*after

gen forcingcbafter=forccb*after
gen forccbtrafter=forccb*tr*after


#########
#Table 2#
#########


reg newper forcing tr after forctr forcingafter trafter forctrafter if forcing<=5 ,cluster(stateyear)

lincom tr+trafter

reg newper forcing tr after forctr forcingafter  trafter forctrafter /*
*/  forcsq forcsqtr forcingsqafter forcsqtrafter  if forcing<=5 ,cluster(stateyear)

lincom tr+trafter

reg newper forcing tr after forctr forcingafter  trafter forctrafter /*
*/  forcsq forcsqtr forcingsqafter forcsqtrafter/*
*/ forccb  forccbtr forcingcbafter forccbtrafter if forcing<=5 ,cluster(stateyear)

lincom tr+trafter

##################################
#Obtaining estimates for Figure 3#
##################################



forvalues x=0/1460 {
quietly reg newper forcing tr forctr  if forcing<=5 & days>`x',cluster(stateyear)
estimates store oldest
lincomest  tr
parmest,label saving(qjps`x'.dta,replace)  
estimates restore oldest
}

forvalues x=1/1460 {
use qjps`x', clear
gen id=`x'
save qjps`x', replace
}

use qjps1, clear
forvalues x=2/1460 {
append using qjps`x'
}


saveold numberofdays.dta, version(12) replace

saveold numberofdays.dta, replace

#######################################
#Recoding code for Table 6 & Table A.8#
#######################################



set more off



cd "/Use/your/cd"



use Data.dta, clear




drop tr forcing forcsqtr trforc forccbtr forcthtr forcsq forccb forcth statelag1 statelag2 stateboth

gen forcing=newpercentagestate-5

gen tr=0
replace tr=1 if forcing>=0
replace tr=. if forcing==.

gen forcsq=forcing^2
gen forccb=forcing^3
gen forcth=forcing^4

gen forctr=forcing*tr
gen forcsqtr=forcsq*tr
gen forccbtr=forccb*tr
gen forcthtr=forcth*tr


drop after  

gen after=0
replace after=1 if days>851
gen trafter=tr*after
gen forcingafter=forcing*after
gen forctrafter=forcing*tr*after



gen forcingsqafter=forcsq*after
gen forcsqtrafter=forcsq*tr*after

gen forcingcbafter=forccb*after
gen forccbtrafter=forccb*tr*after



	bysort  statecode partycode (year month day electiontypecode): gen statelag1=percentagestate[_n-2]
	bysort  statecode partycode (year month day electiontypecode): gen statelag2=percentagestate[_n-3]

	gen stateboth=statelag1
	replace stateboth=statelag2 if newper!=. & statelag1==. & percentagefederal!=.





gen experience=0
	replace experience=1 if stateboth>=5
	gen trexp=tr*exp
	
	gen forcingexp=forcing*exp
	gen forctrexp=forcing*tr*exp



	gen forcingsqexp=forcsq*exp
	gen forcsqtrexp=forcsq*tr*exp

	gen forcingcbexp=forccb*exp
	gen forccbtrexp=forccb*tr*exp

	
	gen expafter=after*exp
	gen forcingexpafter=forcing*experience*after
	gen trexpafter=tr*experience*after
	gen forctrexpafter=forcing*tr*experience*after
	gen forcsqexpafter=forcsq*experience*after
	gen forccbexpafter=forccb*experience*after
	gen forcsqtrexpafter=forcsq*tr*experience*after
	gen forccbtrexpafter=forccb*tr*experience*after


#####################
#Table 6 & Table A.8#
#####################


reg newper forcing tr experience after forctr forcingexp forcingafter trexp expafter trafter forctrexp forctrafter forcingexpafter trexpafter  forctrexpafter/*
*/ if forcing<=5 ,cluster(stateyear)

##########
#Column 1#
##########

lincom tr
lincom tr+trexp
lincom trexp

lincom tr+trafter
lincom tr+trexp+trafter+trexpafter
lincom trexp+trexpafter

##########
#Column 2#
##########



reg newper forcing tr experience after forctr forcingexp forcingafter trexp expafter trafter forctrexp forctrafter forcingexpafter trexpafter  forctrexpafter/*
*/  forcsq forcsqtr forcingsqexp forcingsqafter forcsqtrexp forcsqtrafter forcsqexpafter forcsqtrexpafter/*
*/ if forcing<=5 ,cluster(stateyear)


lincom tr
lincom tr+trexp
lincom trexp

lincom tr+trafter
lincom tr+trexp+trafter+trexpafter
lincom trexp+trexpafter


##########
#Column 3#
##########


reg newper forcing tr experience after forctr forcingexp forcingafter trexp expafter trafter forctrexp forctrafter forcingexpafter trexpafter  forctrexpafter/*
*/  forcsq forcsqtr forcingsqexp forcingsqafter forcsqtrexp forcsqtrafter forcsqexpafter  forcsqtrexpafter/*
*/ forccb  forccbtr forcingcbexp forcingcbafter forccbtrexp forccbtrafter forccbexpafter forccbtrexpafter if forcing<=5,cluster(stateyear)


lincom tr
lincom tr+trexp
lincom trexp

lincom tr+trafter
lincom tr+trexp+trafter+trexpafter
lincom trexp+trexpafter


###########
#Table A.4#
###########

gen after2=0
replace after2=1 if days>912
gen trafter2=tr*after2
gen forcingafter2=forcing*after2
gen forctrafter2=forcing*tr*after2



gen forcingsqafter2=forcsq*after2
gen forcsqtrafter2=forcsq*tr*after2

gen forcingcbafter2=forccb*after2
gen forccbtrafter2=forccb*tr*after2

	
reg newper forcing tr after2 forctr forcingafter2 trafter2 forctrafter2 if forcing<=5 ,cluster(stateyear)

lincom tr
lincom tr+trafter2

reg newper forcing tr after2 forctr forcingafter2  trafter2 forctrafter2 /*
	*/  forcsq forcsqtr forcingsqafter2 forcsqtrafter2  if forcing<=5 ,cluster(stateyear)

lincom tr
lincom tr+trafter2
	
	
reg newper forcing tr after2 forctr forcingafter2  trafter2 forctrafter2 /*
	*/  forcsq forcsqtr forcingsqafter2 forcsqtrafter2/*
	*/ forccb  forccbtr forcingcbafter2 forccbtrafter2 if forcing<=5 ,cluster(stateyear)

lincom tr
lincom tr+trafter2


###########
#Table A.9#
###########


set more off

cd "/Use/your/cd"




use Data.dta, clear

drop tr forcsq forccb forcth forcsqtr forccbtr forcthtr  after

	gen tr=0
	replace tr=1 if forcing>=0
	replace tr=. if forcing==.

	gen forcsq=forcing^2
	gen forccb=forcing^3
	gen forcth=forcing^4

	gen forctr=forcing*tr
	gen forcsqtr=forcsq*tr
	gen forccbtr=forccb*tr
	gen forcthtr=forcth*tr


	gen after=0
	replace after=1 if days>851
	gen trafter=tr*after
	gen forcingafter=forcing*after
	gen forctrafter=forcing*tr*after



	gen forcingsqafter=forcsq*after
	gen forcsqtrafter=forcsq*tr*after

	gen forcingcbafter=forccb*after
	gen forccbtrafter=forccb*tr*after

	
	gen yeartr=year*tr
	gen yearforc=forcing*year
	gen yeartrforc=forcing*tr*year

	gen yearafter=year*after

	gen yeartrafter=year*tr*after
	gen yearforcafter=forcing*year*after
	gen yeartrforcafter=forcing*tr*year*after

	gen tryearafter=tr*year*after

##########
#Column 1#
##########

	reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter  tryearafter/*
	*/ yearforcafter yeartrforcafter if forcing<=5 ,cluster(stateyear)


	forvalues x=1947/2013 {
	quietly reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter  tryearafter/*
	*/ yearforcafter yeartrforcafter if forcing<=5 ,cluster(stateyear)
	estimates store oldest
	lincomest  tr+ `x'*yeartr
	parmest,label saving(qjpsbe`x'.dta,replace)  
	estimates restore oldest
	}


	forvalues x=1947/2013 {
	quietly reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter  tryearafter/*
	*/ yearforcafter yeartrforcafter if forcing<=5 ,cluster(stateyear)
	estimates store oldest
	lincomest tr+trafter+`x'* tryearafter+`x'* yeartr
	parmest,label saving(qjpsab`x'.dta,replace)  
	estimates restore oldest
	}


	
gen yearforcsq=forcsq*year
gen yeartrforcsq=forcsq*tr*year



gen yearforcsqafter=forcsq*year*after
gen yeartrforcsqafter=forcsq*tr*year*after



##########
#Column 2#
##########


reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter yearforcafter tryearafter yeartrforcafter /*
*/ forcsq forcsqtr forcingsqafter yearforcsq  yeartrforcsq forcsqtrafter yearforcsqafter yeartrforcsqafter if forcing<=5 ,cluster(stateyear)


	forvalues x=1947/2013 {
quietly reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter yearforcafter tryearafter yeartrforcafter /*
*/ forcsq forcsqtr forcingsqafter yearforcsq  yeartrforcsq forcsqtrafter yearforcsqafter yeartrforcsqafter if forcing<=5 ,cluster(stateyear)

estimates store oldest
lincomest  tr+ `x'*yeartr
parmest,label saving(qjpsbesq`x'.dta,replace)  
estimates restore oldest
}


forvalues x=1947/2013 {
quietly reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter yearforcafter tryearafter yeartrforcafter /*
*/ forcsq forcsqtr forcingsqafter yearforcsq  yeartrforcsq forcsqtrafter yearforcsqafter yeartrforcsqafter if forcing<=5 ,cluster(stateyear)
estimates store oldest
lincomest tr+trafter+`x'* tryearafter+`x'* yeartr
parmest,label saving(qjpsabsq`x'.dta,replace)  
estimates restore oldest
}




gen yearforccb=forccb*year
gen yeartrforccb=forccb*tr*year


gen yearforccbafter=forccb*year*after
gen yeartrforccbafter=forccb*tr*year*after


##########
#Column 3#
##########


reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter yearforcafter tryearafter/*
*/ yeartrforcafter /*
*/ forcsq forcsqtr forcingsqafter yearforcsq yeartrforcsq forcsqtrafter yearforcsqafter yeartrforcsqafter/*
*/ forccb forccbtr forcingcbafter yearforccb yeartrforccb forccbtrafter yearforccbafter yeartrforccbafter/*
*/ if forcing<=5 ,cluster(stateyear)


forvalues x=1947/2013 {
quietly reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter yearforcafter tryearafter/*
*/ yeartrforcafter /*
*/ forcsq forcsqtr forcingsqafter yearforcsq yeartrforcsq forcsqtrafter yearforcsqafter yeartrforcsqafter/*
*/ forccb forccbtr forcingcbafter yearforccb yeartrforccb forccbtrafter yearforccbafter yeartrforccbafter/*
*/ if forcing<=5 ,cluster(stateyear)
estimates store oldest
lincomest  tr+ `x'*yeartr
parmest,label saving(qjpsbecb`x'.dta,replace)  
estimates restore oldest
}


forvalues x=1947/2013 {
quietly reg newper forcing tr year after forctr yearforc  forcingafter yeartr trafter yearafter yeartrforc forctrafter yearforcafter tryearafter/*
*/ yeartrforcafter /*
*/ forcsq forcsqtr forcingsqafter yearforcsq yeartrforcsq forcsqtrafter yearforcsqafter yeartrforcsqafter/*
*/ forccb forccbtr forcingcbafter yearforccb yeartrforccb forccbtrafter yearforccbafter yeartrforccbafter/*
*/ if forcing<=5 ,cluster(stateyear)
estimates store oldest
lincomest tr+trafter+`x'* tryearafter+`x'* yeartr
parmest,label saving(qjpsabcb`x'.dta,replace)  
estimates restore oldest
}


##################################
#Storing Estimates for Figure A.8#
##################################		
	

	forvalues x=1947/2013 {
	use qjpsbe`x', clear
	gen id=`x'
	save qjpsbe`x', replace
	}

	use qjpsbe1947, clear
	forvalues x=1948/2013 {
	append using qjpsbe`x'
	}
	saveold yearbe, version(12) replace
	saveold yearbe, replace

	forvalues x=1947/2013 {
	use qjpsab`x', clear
	gen id=`x'
	save qjpsab`x', replace
	}

	use qjpsab1947, clear
	forvalues x=1948/2013 {
	append using qjpsab`x'
	}

	saveold yearab, version(12) replace
	saveold yearab, replace
	


	forvalues x=1947/2013 {
	use qjpsbesq`x', clear
	gen id=`x'
	save qjpsbesq`x', replace
	}

	use qjpsbesq1947, clear
	forvalues x=1948/2013 {
	append using qjpsbesq`x'
	}
	saveold yearbesq, version(12) replace
	saveold yearbesq, replace


	forvalues x=1947/2013 {
	use qjpsabsq`x', clear
	gen id=`x'
	save qjpsabsq`x', replace
	}

	use qjpsabsq1947, clear
	forvalues x=1948/2013 {
	append using qjpsabsq`x'
	}

saveold yearabsq, version(12) replace
	saveold yearabsq, replace


	forvalues x=1947/2013 {
	use qjpsbecb`x', clear
	gen id=`x'
	save qjpsbecb`x', replace
	}

	use qjpsbecb1947, clear
	forvalues x=1948/2013 {
	append using qjpsbecb`x'
	}

saveold yearbecb, version(12) replace
	saveold yearbecb, replace

	forvalues x=1947/2013 {
	use qjpsabcb`x', clear
	gen id=`x'
	save qjpsabcb`x', replace
}

	use qjpsabcb1947, clear
	forvalues x=1948/2013 {
	append using qjpsabcb`x'
	}

saveold yearabcb, version(12) replace

saveold yearabcb, replace



forvalues x=0/1460 {

erase qjps`x'.dta 

}


forvalues x=1947/2013 {

erase qjpsbe`x'.dta 

}


forvalues x=1947/2013 {

erase qjpsab`x'.dta 

}


forvalues x=1947/2013 {

erase qjpsabsq`x'.dta 

}


forvalues x=1947/2013 {

erase qjpsbesq`x'.dta 

}

forvalues x=1947/2013 {

erase qjpsbecb`x'.dta 

}


forvalues x=1947/2013 {

erase qjpsabcb`x'.dta 

}

